Class: Azure::Network::Mgmt::V2016_12_01::Models::VerificationIPFlowParameters

Inherits:
Object
  • Object
show all
Includes:
MsRestAzure
Defined in:
lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb

Overview

Parameters that define the IP flow to be verified.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Attribute Details

#directionDirection

5-tuple. Possible values include: ‘Inbound’, ‘Outbound’



20
21
22
# File 'lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb', line 20

def direction
  @direction
end

#local_ipaddressString

addresses.



38
39
40
# File 'lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb', line 38

def local_ipaddress
  @local_ipaddress
end

#local_portString

in the range (0-65535). Support for * for the source port, which depends on the direction.



29
30
31
# File 'lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb', line 29

def local_port
  @local_port
end

#protocolProtocol

‘TCP’, ‘UDP’



24
25
26
# File 'lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb', line 24

def protocol
  @protocol
end

#remote_ipaddressString

IPv4 addresses.



42
43
44
# File 'lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb', line 42

def remote_ipaddress
  @remote_ipaddress
end

#remote_portString

integer in the range (0-65535). Support for * for the source port, which depends on the direction.



34
35
36
# File 'lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb', line 34

def remote_port
  @remote_port
end

#target_nic_resource_idString

is enabled on any of them, then this parameter must be specified. Otherwise optional).



47
48
49
# File 'lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb', line 47

def target_nic_resource_id
  @target_nic_resource_id
end

#target_resource_idString



16
17
18
# File 'lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb', line 16

def target_resource_id
  @target_resource_id
end

Class Method Details

.mapperObject

Mapper for VerificationIPFlowParameters class as Ruby Hash. This will be used for serialization/deserialization.



54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/2016-12-01/generated/azure_mgmt_network/models/verification_ipflow_parameters.rb', line 54

def self.mapper()
  {
    client_side_validation: true,
    required: false,
    serialized_name: 'VerificationIPFlowParameters',
    type: {
      name: 'Composite',
      class_name: 'VerificationIPFlowParameters',
      model_properties: {
        target_resource_id: {
          client_side_validation: true,
          required: true,
          serialized_name: 'targetResourceId',
          type: {
            name: 'String'
          }
        },
        direction: {
          client_side_validation: true,
          required: true,
          serialized_name: 'direction',
          type: {
            name: 'String'
          }
        },
        protocol: {
          client_side_validation: true,
          required: true,
          serialized_name: 'protocol',
          type: {
            name: 'String'
          }
        },
        local_port: {
          client_side_validation: true,
          required: true,
          serialized_name: 'localPort',
          type: {
            name: 'String'
          }
        },
        remote_port: {
          client_side_validation: true,
          required: true,
          serialized_name: 'remotePort',
          type: {
            name: 'String'
          }
        },
        local_ipaddress: {
          client_side_validation: true,
          required: true,
          serialized_name: 'localIPAddress',
          type: {
            name: 'String'
          }
        },
        remote_ipaddress: {
          client_side_validation: true,
          required: true,
          serialized_name: 'remoteIPAddress',
          type: {
            name: 'String'
          }
        },
        target_nic_resource_id: {
          client_side_validation: true,
          required: false,
          serialized_name: 'targetNicResourceId',
          type: {
            name: 'String'
          }
        }
      }
    }
  }
end